@@ -5,7 +5,7 @@ use Mouse;
 
 # ABSTRACT: WebService::Mandrill - an interface to mandrillapp.com's RESTful Web API using Web::API
 
-our $VERSION = '0.8'; # VERSION
+our $VERSION = '0.9'; # VERSION
 
 with 'Web::API';
 
@@ -157,7 +157,10 @@ has 'commands' => (
             },
             render_template => {
                 path      => 'templates/render',
-                mandatory => ['name'],
+                mandatory => [
+                    'template_name', 'template_content.name',
+                    'template_content.content'
+                ],
             },
 
             # exports
@@ -210,7 +213,7 @@ WebService::Mandrill - WebService::Mandrill - an interface to mandrillapp.com's
 
 =head1 VERSION
 
-version 0.8
+version 0.9
 
 =head1 SYNOPSIS
 
